@@ -1,6 +1,6 @@
 require "iconv/iconv.so"
 require "iconv/version"
 
-class Iconv < Data
+class Iconv
   # Your code goes here...
 end
